bayespy.nodes.SwitchingGaussianMarkovChain.move_plates
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.move_plates